@@ -3,11 +3,11 @@ function(ar=0,ma=0,var.noise=1,n.freq=500,  ...)
 { 
     # check causality
      ar.poly <- c(1, -ar)
-     z.ar <- polyroot(ar.poly)
+     z.ar <- base::polyroot(ar.poly)
      if(any(abs(z.ar) <= 1)) cat("WARNING: Model Not Causal", "\n")  
     # check invertibility
      ma.poly <- c(1, ma)
-     z.ma <- polyroot(ma.poly)
+     z.ma <- base::polyroot(ma.poly)
      if(any(abs(z.ma) <= 1)) cat("WARNING: Model Not Invertible", "\n")
      if(any(abs(z.ma) <= 1) || any(abs(z.ar) <= 1) ) stop("Try Again")
     #
